Index: /branches/rel_apv_10_7_2_BugzillaTesting/tools/make_build.sh
===================================================================
--- /branches/rel_apv_10_7_2_BugzillaTesting/tools/make_build.sh	(revision 38735)
+++ /branches/rel_apv_10_7_2_BugzillaTesting/tools/make_build.sh	(working copy)
@@ -8,7 +8,7 @@
 # TODO: support multiple branch (the $2 is reserved for branch)
 
 #global variables
 #flash_url variable is adding, one more commit for Test, one more
 svn_url=""
 flash_url=""
 svn_root=""
@@ -24,6 +24,7 @@
 next_tag=""
 tag_hash=""
 cur_hash=""
+final_commit=""
 
 if [ -z $1 ]; then
 	opt_act="local_build"
@@ -8,7 +8,7 @@
 
 #global variables
-#flash_url variable is adding, one more commit for Test, one more
+#flash_url variable is adding, one more commit for Test, one more, Final commit for testing
 svn_url=""
 flash_url=""
